aboutsummaryrefslogtreecommitdiff
path: root/engines/sword1
diff options
context:
space:
mode:
Diffstat (limited to 'engines/sword1')
-rw-r--r--engines/sword1/animation.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/engines/sword1/animation.cpp b/engines/sword1/animation.cpp
index f6e6e4d1db..1b402c5455 100644
--- a/engines/sword1/animation.cpp
+++ b/engines/sword1/animation.cpp
@@ -144,8 +144,8 @@ bool MoviePlayer::load(uint32 id) {
}
if (_decoder->loadFile(filename)) {
- // The Broken Sword games always use external audio tracks.
- if (_decoder->readSoundHeader() != MKID_BE('NULL'))
+ // The DXA animations in the Broken Sword games always use external audio tracks.
+ if (_decoderType == kVideoDecoderDXA && _decoder->readSoundHeader() != MKID_BE('NULL'))
return false;
} else {
return false;